<?php
/**
 * Plugin Name: CDIA Post Types and Taxonomies
 * Plugin URI: http://ethitter.com
 * Description: Adds custom post types and such. Yay.
 * Version: 0.1
 * Author: Erick Hitter
 * Author URI: http://ethitter.com/
 * License: GPL2+
 */

/**
 *
 */
function cdia_init() {
	$settings = get_option( 'cdia_books' );
	
	// Post type
	register_post_type( 'cdia_books', array(
		'label' => 'Books',
		'public' => isset( $settings['post_type_vis'] ),
		'can_export' => isset( $settings['post_type_export'] ),
		'has_archive' => true,
		'rewrite' => array(
			'slug' => 'book'
		)
	) );

	// Taxonomy
	register_taxonomy( 'cdia_genres', 'cdia_books', array(
		'label' => 'Genres',
		'public' => isset( $settings['tax_vis'] ),
		'show_admin_column' => true,
		'hierarchical' => true,
		'rewrite' => array(
			'slug' => 'genre'
		)
	) );

// 	register_taxonomy_for_object_type( 'cdia_genres', 'page' );
// 	register_taxonomy_for_object_type( 'category', 'cdia_books' );
}
add_action( 'init', 'cdia_init' );

/**
 * Register metaboxes
 *
 * @uses add_meta_box
 * @action add_meta_boxes
 * @return null
 */
function cdia_register_metabox() {
	add_meta_box( 'cdia-books-author', 'Author',
	 'cdia_author_metabox', 'cdia_books' );
}
add_action( 'add_meta_boxes', 'cdia_register_metabox' );

/**
 *
 */
function cdia_author_metabox() {
	$author = get_post_meta( get_the_ID(), '_cdia_author', true );

	?>
	<input type="text" name="cdia_author" class="large-text" value="<?php echo esc_attr( $author ); ?>" />
	<?php
	wp_nonce_field( 'cdia-author', 'cdia_author_nonce' );
}

/**
 *
 */
function cdia_save_metabox( $post_id ) {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
		return;

	if (
		isset( $_POST['cdia_author_nonce'] ) &&
		wp_verify_nonce( $_POST['cdia_author_nonce'], 'cdia-author' ) &&
		isset( $_POST['cdia_author'] )
	) {
		$author = $_POST['cdia_author'];
		$author = sanitize_text_field( $author );

		if ( empty( $author ) )
			delete_post_meta( $post_id, '_cdia_author' );
		else
			update_post_meta( $post_id, '_cdia_author', $author );
	}
}
add_action( 'save_post', 'cdia_save_metabox' );

/**
 *
 */
function cdia_admin_init() {
	register_setting( 'cdia_books', 'cdia_books', 'cdia_books_validate' );
}
add_action( 'admin_init', 'cdia_admin_init' );

/**
 *
 */
function cdia_admin_menu() {
	add_options_page( 'CDIA Books', 'CDIA Books', 'manage_options', 'cdia-books', 'cdia_books_screen' );
}
add_action( 'admin_menu', 'cdia_admin_menu' );

/**
 *
 */
function cdia_books_screen() {
	$settings = get_option( 'cdia_books' );

	?>
	<div class="wrap">
		<h2><?php echo get_admin_page_title(); ?></h2>
		
		<form action="options.php" method="post">
			<?php settings_fields( 'cdia_books' ); ?>
			
			<table class="form-table">
				<tr>
					<th><label for="post-type-vis">Books visibility</label></th>
					<td>
						<input type="checkbox" name="cdia_books[post_type_vis]" id="post-type-vis" value="1"<?php checked( isset( $settings['post_type_vis'] ) ); ?> />
						<label for="post-type-vis">Show the Books edit interface?</label>
					</td>
				</tr>
				<tr>
					<th><label for="post-type-export">Export Books</label></th>
					<td>
						<input type="checkbox" name="cdia_books[post_type_export]" id="post-type-export" value="1"<?php checked( isset( $settings['post_type_export'] ) ); ?> />
						<label for="post-type-export">Can books be exported?</label>
					</td>
				</tr>
				<tr>
					<th><label for="tax-vis">Genre visibility</label></th>
					<td>
						<input type="checkbox" name="cdia_books[tax_vis]" id="tax-vis" value="1"<?php checked( isset( $settings['tax_vis'] ) ); ?> />
						<label for="tax-vis">Show the Genre edit interface?</label>
					</td>
				</tr>
				<!-- 
<tr>
					<th><label for="tax-export">Export Genres</label></th>
					<td>
						<input type="checkbox" name="cdia_books[tax_export]" id="tax-export" value="1"<?php checked( isset( $settings['tax_export'] ) ); ?> />
						<label for="tax-export">Can genres be exported?</label>
					</td>
				</tr>
 -->
			</table>
			
			<?php submit_button(); ?>
		</form>
	</div><!-- .wrap -->
	<?php
}



function cdia_books_validate( $options ) {
	$options_validated = array();
	
	if ( is_array( $options ) ) {
		foreach ( $options as $name => $value ) {
			$options_validated[ $name ] = true;
		}
	}
	
	return $options_validated;
}

















